@@ -59,8 +59,10 @@ class Device(Events):
     __runner_log = True
     watcher_list = []
     __main_conn, __watcher_conn = Pipe()
+    __width = 0
+    __height = 0
 
-    def __init__(self, host="192.168.100.100", port=8080, runner_log=True, main=True):
+    def __init__(self, host="192.168.100.100", port=10008, runner_log=True, main=True):
         super().__init__(d=self)
         self.__runner_log = runner_log
         self.con.host = host
@@ -68,6 +70,7 @@ class Device(Events):
         self.con.connect()
         self.__serialNumber = str(self.con.get(path="getSerialNumber").read(), 'utf-8')
         self.__osVersion = str(self.con.get(path="getOsVersion").read(), 'utf-8')
+        self.__set_display_size()
         if main:
             _start_watcher(host, port, self.__watcher_conn)
             syslog_thread = threading.Thread(target=self.__logger)
@@ -156,6 +159,17 @@ class Device(Events):
         image.close()
         return file_name
 
+    def __set_display_size(self):
+        image_data = str(self.con.get(path="getScreenShot").read(), 'utf-8')
+        self.__height = int(image_data.split(",")[1])
+        self.__width = int(image_data.split(",")[2])
+
+    def display_width(self):
+        return self.__width
+
+    def display_height(self):
+        return self.__height
+
     def get_xpath(self, sop_id, key):
         if not os.path.exists(self.__xpath_file):
             f = open(self.__xpath_file, "w")
@@ -217,6 +231,9 @@ class Device(Events):
     def uninstall(self, sopid):
         return bool(int(str(self.con.get(path="uninstall", args="sopid=" + sopid).read(), 'utf-8')))
 
+    def system_time(self):
+        return int(str(self.con.get(path="uninstall").read(), 'utf-8'))
+
     def log(self, level, text):
         pass
         # if not self.__runner_log:
